You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@commons.apache.org by er...@apache.org on 2012/02/14 17:18:50 UTC

svn commit: r1244107 [8/18] - in /commons/proper/math/trunk: ./ src/main/java/org/apache/commons/math/ src/main/java/org/apache/commons/math3/ src/main/java/org/apache/commons/math3/analysis/ src/main/java/org/apache/commons/math3/analysis/function/ sr...

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/SingularValueDecomposition.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/SingularValueDecomposition.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/SingularValueDecomposition.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/SingularValueDecomposition.java Tue Feb 14 16:17:55 2012
@@ -14,12 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.linear;
+package org.apache.commons.math3.linear;
 
-import org.apache.commons.math.exception.NumberIsTooLargeException;
-import org.apache.commons.math.exception.util.LocalizedFormats;
-import org.apache.commons.math.util.FastMath;
-import org.apache.commons.math.util.Precision;
+import org.apache.commons.math3.exception.NumberIsTooLargeException;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
+import org.apache.commons.math3.util.FastMath;
+import org.apache.commons.math3.util.Precision;
 
 /**
  * Calculates the compact Singular Value Decomposition of a matrix.
@@ -692,7 +692,7 @@ public class SingularValueDecomposition 
          * </p>
          * @param b Right-hand side of the equation A &times; X = B
          * @return a vector X that minimizes the two norm of A &times; X - B
-         * @throws org.apache.commons.math.exception.DimensionMismatchException
+         * @throws org.apache.commons.math3.exception.DimensionMismatchException
          * if the matrices dimensions do not match.
          */
         public RealVector solve(final RealVector b) {
@@ -708,7 +708,7 @@ public class SingularValueDecomposition 
          *
          * @param b Right-hand side of the equation A &times; X = B
          * @return a matrix X that minimizes the two norm of A &times; X - B
-         * @throws org.apache.commons.math.exception.DimensionMismatchException
+         * @throws org.apache.commons.math3.exception.DimensionMismatchException
          * if the matrices dimensions do not match.
          */
         public RealMatrix solve(final RealMatrix b) {

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/SparseFieldMatrix.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/SparseFieldMatrix.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/SparseFieldMatrix.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/SparseFieldMatrix.java Tue Feb 14 16:17:55 2012
@@ -14,11 +14,11 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.linear;
+package org.apache.commons.math3.linear;
 
-import org.apache.commons.math.Field;
-import org.apache.commons.math.FieldElement;
-import org.apache.commons.math.util.OpenIntToFieldHashMap;
+import org.apache.commons.math3.Field;
+import org.apache.commons.math3.FieldElement;
+import org.apache.commons.math3.util.OpenIntToFieldHashMap;
 
 /**
  * Sparse matrix implementation based on an open addressed map.
@@ -55,7 +55,7 @@ public class SparseFieldMatrix<T extends
      * @param field Field to which the elements belong.
      * @param rowDimension Number of rows in the new matrix.
      * @param columnDimension Number of columns in the new matrix.
-     * @throws org.apache.commons.math.exception.NotStrictlyPositiveException
+     * @throws org.apache.commons.math3.exception.NotStrictlyPositiveException
      * if row or column dimension is not positive.
      */
     public SparseFieldMatrix(final Field<T> field,

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/SparseFieldVector.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/SparseFieldVector.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/SparseFieldVector.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/SparseFieldVector.java Tue Feb 14 16:17:55 2012
@@ -14,16 +14,16 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.linear;
+package org.apache.commons.math3.linear;
 
 import java.io.Serializable;
 import java.lang.reflect.Array;
 
-import org.apache.commons.math.Field;
-import org.apache.commons.math.FieldElement;
-import org.apache.commons.math.exception.OutOfRangeException;
-import org.apache.commons.math.exception.DimensionMismatchException;
-import org.apache.commons.math.util.OpenIntToFieldHashMap;
+import org.apache.commons.math3.Field;
+import org.apache.commons.math3.FieldElement;
+import org.apache.commons.math3.exception.OutOfRangeException;
+import org.apache.commons.math3.exception.DimensionMismatchException;
+import org.apache.commons.math3.util.OpenIntToFieldHashMap;
 
 /**
  * This class implements the {@link FieldVector} interface with a {@link OpenIntToFieldHashMap} backing store.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/SparseRealMatrix.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/SparseRealMatrix.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/SparseRealMatrix.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/SparseRealMatrix.java Tue Feb 14 16:17:55 2012
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.linear;
+package org.apache.commons.math3.linear;
 
 /**
  * Marker interface for {@link RealMatrix} implementations that require sparse backing storage

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/SparseRealVector.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/SparseRealVector.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/SparseRealVector.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/SparseRealVector.java Tue Feb 14 16:17:55 2012
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.linear;
+package org.apache.commons.math3.linear;
 
 /**
  * Marker class for RealVectors that require sparse backing storage

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/SymmLQ.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/SymmLQ.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/SymmLQ.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/SymmLQ.java Tue Feb 14 16:17:55 2012
@@ -14,15 +14,15 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.linear;
+package org.apache.commons.math3.linear;
 
-import org.apache.commons.math.exception.DimensionMismatchException;
-import org.apache.commons.math.exception.MaxCountExceededException;
-import org.apache.commons.math.exception.NullArgumentException;
-import org.apache.commons.math.exception.util.ExceptionContext;
-import org.apache.commons.math.util.FastMath;
-import org.apache.commons.math.util.IterationManager;
-import org.apache.commons.math.util.MathUtils;
+import org.apache.commons.math3.exception.DimensionMismatchException;
+import org.apache.commons.math3.exception.MaxCountExceededException;
+import org.apache.commons.math3.exception.NullArgumentException;
+import org.apache.commons.math3.exception.util.ExceptionContext;
+import org.apache.commons.math3.util.FastMath;
+import org.apache.commons.math3.util.IterationManager;
+import org.apache.commons.math3.util.MathUtils;
 
 /**
  * <p>
@@ -932,7 +932,7 @@ public class SymmLQ
      * dimensions inconsistent with {@code a}
      * @throws MaxCountExceededException at exhaustion of the iteration count,
      * unless a custom
-     * {@link org.apache.commons.math.util.Incrementor.MaxCountExceededCallback callback}
+     * {@link org.apache.commons.math3.util.Incrementor.MaxCountExceededCallback callback}
      * has been set at construction
      * @throws NonSelfAdjointOperatorException if {@link #getCheck()} is
      * {@code true}, and {@code a} or {@code minv} is not self-adjoint
@@ -1020,7 +1020,7 @@ public class SymmLQ
      * inconsistent with {@code a}
      * @throws MaxCountExceededException at exhaustion of the iteration count,
      * unless a custom
-     * {@link org.apache.commons.math.util.Incrementor.MaxCountExceededCallback callback}
+     * {@link org.apache.commons.math3.util.Incrementor.MaxCountExceededCallback callback}
      * has been set at construction
      * @throws NonSelfAdjointOperatorException if {@link #getCheck()} is
      * {@code true}, and {@code a} is not self-adjoint
@@ -1112,7 +1112,7 @@ public class SymmLQ
      * {@code x} have dimensions inconsistent with {@code a}.
      * @throws MaxCountExceededException at exhaustion of the iteration count,
      * unless a custom
-     * {@link org.apache.commons.math.util.Incrementor.MaxCountExceededCallback callback}
+     * {@link org.apache.commons.math3.util.Incrementor.MaxCountExceededCallback callback}
      * has been set at construction
      * @throws NonSelfAdjointOperatorException if {@link #getCheck()} is
      * {@code true}, and {@code a} or {@code minv} is not self-adjoint

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/TriDiagonalTransformer.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/TriDiagonalTransformer.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/TriDiagonalTransformer.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/TriDiagonalTransformer.java Tue Feb 14 16:17:55 2012
@@ -15,11 +15,11 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.linear;
+package org.apache.commons.math3.linear;
 
 import java.util.Arrays;
 
-import org.apache.commons.math.util.FastMath;
+import org.apache.commons.math3.util.FastMath;
 
 
 /**

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/package-info.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/package-info.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/package-info.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/linear/package-info.java Tue Feb 14 16:17:55 2012
@@ -17,4 +17,4 @@
 /**
  * Linear algebra support.
  */
-package org.apache.commons.math.linear;
+package org.apache.commons.math3.linear;

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/AbstractIntegrator.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/AbstractIntegrator.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/AbstractIntegrator.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/AbstractIntegrator.java Tue Feb 14 16:17:55 2012
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.ode;
+package org.apache.commons.math3.ode;
 
 import java.util.ArrayList;
 import java.util.Collection;
@@ -26,21 +26,21 @@ import java.util.List;
 import java.util.SortedSet;
 import java.util.TreeSet;
 
-import org.apache.commons.math.analysis.solvers.BracketingNthOrderBrentSolver;
-import org.apache.commons.math.analysis.solvers.UnivariateSolver;
-import org.apache.commons.math.exception.DimensionMismatchException;
-import org.apache.commons.math.exception.MathIllegalArgumentException;
-import org.apache.commons.math.exception.MathIllegalStateException;
-import org.apache.commons.math.exception.MaxCountExceededException;
-import org.apache.commons.math.exception.NumberIsTooSmallException;
-import org.apache.commons.math.exception.util.LocalizedFormats;
-import org.apache.commons.math.ode.events.EventHandler;
-import org.apache.commons.math.ode.events.EventState;
-import org.apache.commons.math.ode.sampling.AbstractStepInterpolator;
-import org.apache.commons.math.ode.sampling.StepHandler;
-import org.apache.commons.math.util.FastMath;
-import org.apache.commons.math.util.Incrementor;
-import org.apache.commons.math.util.Precision;
+import org.apache.commons.math3.analysis.solvers.BracketingNthOrderBrentSolver;
+import org.apache.commons.math3.analysis.solvers.UnivariateSolver;
+import org.apache.commons.math3.exception.DimensionMismatchException;
+import org.apache.commons.math3.exception.MathIllegalArgumentException;
+import org.apache.commons.math3.exception.MathIllegalStateException;
+import org.apache.commons.math3.exception.MaxCountExceededException;
+import org.apache.commons.math3.exception.NumberIsTooSmallException;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
+import org.apache.commons.math3.ode.events.EventHandler;
+import org.apache.commons.math3.ode.events.EventState;
+import org.apache.commons.math3.ode.sampling.AbstractStepInterpolator;
+import org.apache.commons.math3.ode.sampling.StepHandler;
+import org.apache.commons.math3.util.FastMath;
+import org.apache.commons.math3.util.Incrementor;
+import org.apache.commons.math3.util.Precision;
 
 /**
  * Base class managing common boilerplate for all integrators.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/AbstractParameterizable.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/AbstractParameterizable.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/AbstractParameterizable.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/AbstractParameterizable.java Tue Feb 14 16:17:55 2012
@@ -14,13 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.ode;
+package org.apache.commons.math3.ode;
 
 import java.util.ArrayList;
 import java.util.Collection;
 
-import org.apache.commons.math.exception.MathIllegalArgumentException;
-import org.apache.commons.math.exception.util.LocalizedFormats;
+import org.apache.commons.math3.exception.MathIllegalArgumentException;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
 
 /** This abstract class provides boilerplate parameters list.
  *

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/ContinuousOutputModel.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/ContinuousOutputModel.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/ContinuousOutputModel.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/ContinuousOutputModel.java Tue Feb 14 16:17:55 2012
@@ -15,18 +15,18 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.ode;
+package org.apache.commons.math3.ode;
 
 import java.io.Serializable;
 import java.util.ArrayList;
 import java.util.List;
 
-import org.apache.commons.math.exception.DimensionMismatchException;
-import org.apache.commons.math.exception.MathIllegalArgumentException;
-import org.apache.commons.math.exception.util.LocalizedFormats;
-import org.apache.commons.math.ode.sampling.StepHandler;
-import org.apache.commons.math.ode.sampling.StepInterpolator;
-import org.apache.commons.math.util.FastMath;
+import org.apache.commons.math3.exception.DimensionMismatchException;
+import org.apache.commons.math3.exception.MathIllegalArgumentException;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
+import org.apache.commons.math3.ode.sampling.StepHandler;
+import org.apache.commons.math3.ode.sampling.StepInterpolator;
+import org.apache.commons.math3.util.FastMath;
 
 /**
  * This class stores all information provided by an ODE integrator
@@ -77,7 +77,7 @@ import org.apache.commons.math.util.Fast
  * ContinuousOutputModel instance can be important if the state vector
  * is large, if the integration interval is long or if the steps are
  * small (which can result from small tolerance settings in {@link
- * org.apache.commons.math.ode.nonstiff.AdaptiveStepsizeIntegrator adaptive
+ * org.apache.commons.math3.ode.nonstiff.AdaptiveStepsizeIntegrator adaptive
  * step size integrators}).</p>
  *
  * @see StepHandler

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/EquationsMapper.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/EquationsMapper.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/EquationsMapper.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/EquationsMapper.java Tue Feb 14 16:17:55 2012
@@ -15,11 +15,11 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.ode;
+package org.apache.commons.math3.ode;
 
 import java.io.Serializable;
 
-import org.apache.commons.math.exception.DimensionMismatchException;
+import org.apache.commons.math3.exception.DimensionMismatchException;
 
 /**
  * Class mapping the part of a complete state or derivative that pertains

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/ExpandableStatefulODE.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/ExpandableStatefulODE.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/ExpandableStatefulODE.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/ExpandableStatefulODE.java Tue Feb 14 16:17:55 2012
@@ -14,12 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.ode;
+package org.apache.commons.math3.ode;
 
 import java.util.ArrayList;
 import java.util.List;
 
-import org.apache.commons.math.exception.DimensionMismatchException;
+import org.apache.commons.math3.exception.DimensionMismatchException;
 
 
 /**

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/FirstOrderConverter.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/FirstOrderConverter.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/FirstOrderConverter.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/FirstOrderConverter.java Tue Feb 14 16:17:55 2012
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.ode;
+package org.apache.commons.math3.ode;
 
 
 /** This class converts second order differential equations to first

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/FirstOrderDifferentialEquations.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/FirstOrderDifferentialEquations.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/FirstOrderDifferentialEquations.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/FirstOrderDifferentialEquations.java Tue Feb 14 16:17:55 2012
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.ode;
+package org.apache.commons.math3.ode;
 
 
 

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/FirstOrderIntegrator.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/FirstOrderIntegrator.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/JacobianMatrices.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/JacobianMatrices.java Tue Feb 14 16:17:55 2012
@@ -14,15 +14,15 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.ode;
+package org.apache.commons.math3.ode;
 
 import java.lang.reflect.Array;
 import java.util.ArrayList;
 import java.util.List;
 
-import org.apache.commons.math.exception.DimensionMismatchException;
-import org.apache.commons.math.exception.MathIllegalArgumentException;
-import org.apache.commons.math.exception.util.LocalizedFormats;
+import org.apache.commons.math3.exception.DimensionMismatchException;
+import org.apache.commons.math3.exception.MathIllegalArgumentException;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
 
 /**
  * This class defines a set of {@link SecondaryEquations secondary equations} to

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/MainStateJacobianProvider.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/MainStateJacobianProvider.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/MainStateJacobianProvider.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/MainStateJacobianProvider.java Tue Feb 14 16:17:55 2012
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.ode;
+package org.apache.commons.math3.ode;
 
 /** Interface expanding {@link FirstOrderDifferentialEquations first order
  *  differential equations} in order to compute exactly the main state jacobian

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/MultistepIntegrator.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/MultistepIntegrator.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/MultistepIntegrator.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/MultistepIntegrator.java Tue Feb 14 16:17:55 2012
@@ -15,17 +15,17 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.ode;
+package org.apache.commons.math3.ode;
 
-import org.apache.commons.math.exception.MathIllegalArgumentException;
-import org.apache.commons.math.exception.MathIllegalStateException;
-import org.apache.commons.math.exception.util.LocalizedFormats;
-import org.apache.commons.math.linear.Array2DRowRealMatrix;
-import org.apache.commons.math.ode.nonstiff.AdaptiveStepsizeIntegrator;
-import org.apache.commons.math.ode.nonstiff.DormandPrince853Integrator;
-import org.apache.commons.math.ode.sampling.StepHandler;
-import org.apache.commons.math.ode.sampling.StepInterpolator;
-import org.apache.commons.math.util.FastMath;
+import org.apache.commons.math3.exception.MathIllegalArgumentException;
+import org.apache.commons.math3.exception.MathIllegalStateException;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
+import org.apache.commons.math3.linear.Array2DRowRealMatrix;
+import org.apache.commons.math3.ode.nonstiff.AdaptiveStepsizeIntegrator;
+import org.apache.commons.math3.ode.nonstiff.DormandPrince853Integrator;
+import org.apache.commons.math3.ode.sampling.StepHandler;
+import org.apache.commons.math3.ode.sampling.StepInterpolator;
+import org.apache.commons.math3.util.FastMath;
 
 /**
  * This class is the base class for multistep integrators for Ordinary
@@ -53,8 +53,8 @@ import org.apache.commons.math.util.Fast
  * factor is therefore set to a quite low value: 2<sup>1/order</sup>.
  * </p>
  *
- * @see org.apache.commons.math.ode.nonstiff.AdamsBashforthIntegrator
- * @see org.apache.commons.math.ode.nonstiff.AdamsMoultonIntegrator
+ * @see org.apache.commons.math3.ode.nonstiff.AdamsBashforthIntegrator
+ * @see org.apache.commons.math3.ode.nonstiff.AdamsMoultonIntegrator
  * @version $Id$
  * @since 2.0
  */

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/ODEIntegrator.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/ODEIntegrator.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/ODEIntegrator.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/ODEIntegrator.java Tue Feb 14 16:17:55 2012
@@ -15,13 +15,13 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.ode;
+package org.apache.commons.math3.ode;
 
 import java.util.Collection;
 
-import org.apache.commons.math.analysis.solvers.UnivariateSolver;
-import org.apache.commons.math.ode.events.EventHandler;
-import org.apache.commons.math.ode.sampling.StepHandler;
+import org.apache.commons.math3.analysis.solvers.UnivariateSolver;
+import org.apache.commons.math3.ode.events.EventHandler;
+import org.apache.commons.math3.ode.sampling.StepHandler;
 
 /**
  * This interface defines the common parts shared by integrators

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/ParameterConfiguration.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/ParameterConfiguration.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/ParameterConfiguration.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/ParameterConfiguration.java Tue Feb 14 16:17:55 2012
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.ode;
+package org.apache.commons.math3.ode;
 
 import java.io.Serializable;
 

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/ParameterJacobianProvider.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/ParameterJacobianProvider.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/ParameterJacobianProvider.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/ParameterJacobianProvider.java Tue Feb 14 16:17:55 2012
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.ode;
+package org.apache.commons.math3.ode;
 
-import org.apache.commons.math.exception.MathIllegalArgumentException;
+import org.apache.commons.math3.exception.MathIllegalArgumentException;
 
 /** Interface to compute exactly Jacobian matrix for some parameter
  *  when computing {@link JacobianMatrices partial derivatives equations}.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/ParameterJacobianWrapper.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/ParameterJacobianWrapper.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/ParameterJacobianWrapper.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/ParameterJacobianWrapper.java Tue Feb 14 16:17:55 2012
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.ode;
+package org.apache.commons.math3.ode;
 
 import java.util.Collection;
 import java.util.HashMap;

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/Parameterizable.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/Parameterizable.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/Parameterizable.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/Parameterizable.java Tue Feb 14 16:17:55 2012
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.ode;
+package org.apache.commons.math3.ode;
 
 import java.util.Collection;
 

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/ParameterizedODE.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/ParameterizedODE.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/ParameterizedODE.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/ParameterizedODE.java Tue Feb 14 16:17:55 2012
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.ode;
+package org.apache.commons.math3.ode;
 
 /** Interface to compute by finite difference Jacobian matrix for some parameter
  *  when computing {@link JacobianMatrices partial derivatives equations}.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/ParameterizedWrapper.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/ParameterizedWrapper.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/ParameterizedWrapper.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/ParameterizedWrapper.java Tue Feb 14 16:17:55 2012
@@ -14,13 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.commons.math.ode;
+package org.apache.commons.math3.ode;
 
 import java.util.ArrayList;
 import java.util.Collection;
 
-import org.apache.commons.math.exception.MathIllegalArgumentException;
-import org.apache.commons.math.exception.util.LocalizedFormats;
+import org.apache.commons.math3.exception.MathIllegalArgumentException;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
 
 /** Wrapper class enabling {@link FirstOrderDifferentialEquations basic simple}
  *  ODE instances to be used when processing {@link JacobianMatrices}.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/SecondOrderDifferentialEquations.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/SecondOrderDifferentialEquations.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/SecondOrderDifferentialEquations.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/SecondOrderDifferentialEquations.java Tue Feb 14 16:17:55 2012
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.ode;
+package org.apache.commons.math3.ode;
 
 
 /** This interface represents a second order differential equations set.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/SecondOrderIntegrator.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/SecondOrderIntegrator.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/SecondOrderIntegrator.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/SecondOrderIntegrator.java Tue Feb 14 16:17:55 2012
@@ -15,10 +15,10 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.ode;
+package org.apache.commons.math3.ode;
 
-import org.apache.commons.math.exception.MathIllegalArgumentException;
-import org.apache.commons.math.exception.MathIllegalStateException;
+import org.apache.commons.math3.exception.MathIllegalArgumentException;
+import org.apache.commons.math3.exception.MathIllegalStateException;
 
 
 /** This interface represents a second order integrator for

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/SecondaryEquations.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/SecondaryEquations.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/SecondaryEquations.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/SecondaryEquations.java Tue Feb 14 16:17:55 2012
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.ode;
+package org.apache.commons.math3.ode;
 
 /**
  * This interface allows users to add secondary differential equations to a primary

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/events/EventHandler.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/events/EventHandler.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/events/EventState.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/events/EventState.java Tue Feb 14 16:17:55 2012
@@ -15,18 +15,18 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.ode.events;
+package org.apache.commons.math3.ode.events;
 
-import org.apache.commons.math.analysis.UnivariateFunction;
-import org.apache.commons.math.analysis.solvers.AllowedSolution;
-import org.apache.commons.math.analysis.solvers.BracketedUnivariateSolver;
-import org.apache.commons.math.analysis.solvers.PegasusSolver;
-import org.apache.commons.math.analysis.solvers.UnivariateSolver;
-import org.apache.commons.math.analysis.solvers.UnivariateSolverUtils;
-import org.apache.commons.math.exception.ConvergenceException;
-import org.apache.commons.math.ode.events.EventHandler;
-import org.apache.commons.math.ode.sampling.StepInterpolator;
-import org.apache.commons.math.util.FastMath;
+import org.apache.commons.math3.analysis.UnivariateFunction;
+import org.apache.commons.math3.analysis.solvers.AllowedSolution;
+import org.apache.commons.math3.analysis.solvers.BracketedUnivariateSolver;
+import org.apache.commons.math3.analysis.solvers.PegasusSolver;
+import org.apache.commons.math3.analysis.solvers.UnivariateSolver;
+import org.apache.commons.math3.analysis.solvers.UnivariateSolverUtils;
+import org.apache.commons.math3.exception.ConvergenceException;
+import org.apache.commons.math3.ode.events.EventHandler;
+import org.apache.commons.math3.ode.sampling.StepInterpolator;
+import org.apache.commons.math3.util.FastMath;
 
 /** This class handles the state for one {@link EventHandler
  * event handler} during integration steps.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/events/package-info.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/events/package-info.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/events/package-info.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/events/package-info.java Tue Feb 14 16:17:55 2012
@@ -23,7 +23,7 @@
  *
  * <p>
  * Discrete events detection is based on switching functions. The user provides
- * a simple {@link org.apache.commons.math.ode.events.EventHandler#g g(t, y)}
+ * a simple {@link org.apache.commons.math3.ode.events.EventHandler#g g(t, y)}
  * function depending on the current time and state. The integrator will monitor
  * the value of the function throughout integration range and will trigger the
  * event when its sign changes. The magnitude of the value is almost irrelevant,
@@ -93,4 +93,4 @@
  *
  *
  */
-package org.apache.commons.math.ode.events;
+package org.apache.commons.math3.ode.events;

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/AdamsBashforthIntegrator.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/AdamsBashforthIntegrator.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/AdamsBashforthIntegrator.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/AdamsBashforthIntegrator.java Tue Feb 14 16:17:55 2012
@@ -15,14 +15,14 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.ode.nonstiff;
+package org.apache.commons.math3.ode.nonstiff;
 
-import org.apache.commons.math.exception.MathIllegalArgumentException;
-import org.apache.commons.math.exception.MathIllegalStateException;
-import org.apache.commons.math.linear.Array2DRowRealMatrix;
-import org.apache.commons.math.ode.ExpandableStatefulODE;
-import org.apache.commons.math.ode.sampling.NordsieckStepInterpolator;
-import org.apache.commons.math.util.FastMath;
+import org.apache.commons.math3.exception.MathIllegalArgumentException;
+import org.apache.commons.math3.exception.MathIllegalStateException;
+import org.apache.commons.math3.linear.Array2DRowRealMatrix;
+import org.apache.commons.math3.ode.ExpandableStatefulODE;
+import org.apache.commons.math3.ode.sampling.NordsieckStepInterpolator;
+import org.apache.commons.math3.util.FastMath;
 
 
 /**

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/AdamsIntegrator.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/AdamsIntegrator.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/AdamsIntegrator.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/AdamsIntegrator.java Tue Feb 14 16:17:55 2012
@@ -15,13 +15,13 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.ode.nonstiff;
+package org.apache.commons.math3.ode.nonstiff;
 
-import org.apache.commons.math.exception.MathIllegalArgumentException;
-import org.apache.commons.math.exception.MathIllegalStateException;
-import org.apache.commons.math.linear.Array2DRowRealMatrix;
-import org.apache.commons.math.ode.ExpandableStatefulODE;
-import org.apache.commons.math.ode.MultistepIntegrator;
+import org.apache.commons.math3.exception.MathIllegalArgumentException;
+import org.apache.commons.math3.exception.MathIllegalStateException;
+import org.apache.commons.math3.linear.Array2DRowRealMatrix;
+import org.apache.commons.math3.ode.ExpandableStatefulODE;
+import org.apache.commons.math3.ode.MultistepIntegrator;
 
 
 /** Base class for {@link AdamsBashforthIntegrator Adams-Bashforth} and

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/AdamsMoultonIntegrator.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/AdamsMoultonIntegrator.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/AdamsMoultonIntegrator.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/AdamsMoultonIntegrator.java Tue Feb 14 16:17:55 2012
@@ -15,17 +15,17 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.ode.nonstiff;
+package org.apache.commons.math3.ode.nonstiff;
 
 import java.util.Arrays;
 
-import org.apache.commons.math.exception.MathIllegalArgumentException;
-import org.apache.commons.math.exception.MathIllegalStateException;
-import org.apache.commons.math.linear.Array2DRowRealMatrix;
-import org.apache.commons.math.linear.RealMatrixPreservingVisitor;
-import org.apache.commons.math.ode.ExpandableStatefulODE;
-import org.apache.commons.math.ode.sampling.NordsieckStepInterpolator;
-import org.apache.commons.math.util.FastMath;
+import org.apache.commons.math3.exception.MathIllegalArgumentException;
+import org.apache.commons.math3.exception.MathIllegalStateException;
+import org.apache.commons.math3.linear.Array2DRowRealMatrix;
+import org.apache.commons.math3.linear.RealMatrixPreservingVisitor;
+import org.apache.commons.math3.ode.ExpandableStatefulODE;
+import org.apache.commons.math3.ode.sampling.NordsieckStepInterpolator;
+import org.apache.commons.math3.util.FastMath;
 
 
 /**

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/AdamsNordsieckTransformer.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/AdamsNordsieckTransformer.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/AdamsNordsieckTransformer.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/AdamsNordsieckTransformer.java Tue Feb 14 16:17:55 2012
@@ -15,22 +15,22 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.ode.nonstiff;
+package org.apache.commons.math3.ode.nonstiff;
 
 import java.util.Arrays;
 import java.util.HashMap;
 import java.util.Map;
 
-import org.apache.commons.math.fraction.BigFraction;
-import org.apache.commons.math.linear.Array2DRowFieldMatrix;
-import org.apache.commons.math.linear.Array2DRowRealMatrix;
-import org.apache.commons.math.linear.ArrayFieldVector;
-import org.apache.commons.math.linear.FieldDecompositionSolver;
-import org.apache.commons.math.linear.FieldLUDecomposition;
-import org.apache.commons.math.linear.FieldMatrix;
-import org.apache.commons.math.linear.MatrixUtils;
-import org.apache.commons.math.linear.QRDecomposition;
-import org.apache.commons.math.linear.RealMatrix;
+import org.apache.commons.math3.fraction.BigFraction;
+import org.apache.commons.math3.linear.Array2DRowFieldMatrix;
+import org.apache.commons.math3.linear.Array2DRowRealMatrix;
+import org.apache.commons.math3.linear.ArrayFieldVector;
+import org.apache.commons.math3.linear.FieldDecompositionSolver;
+import org.apache.commons.math3.linear.FieldLUDecomposition;
+import org.apache.commons.math3.linear.FieldMatrix;
+import org.apache.commons.math3.linear.MatrixUtils;
+import org.apache.commons.math3.linear.QRDecomposition;
+import org.apache.commons.math3.linear.RealMatrix;
 
 /** Transformer to Nordsieck vectors for Adams integrators.
  * <p>This class is used by {@link AdamsBashforthIntegrator Adams-Bashforth} and

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/AdaptiveStepsizeIntegrator.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/AdaptiveStepsizeIntegrator.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/ClassicalRungeKuttaIntegrator.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/ClassicalRungeKuttaIntegrator.java Tue Feb 14 16:17:55 2012
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.ode.nonstiff;
+package org.apache.commons.math3.ode.nonstiff;
 
 
 /**

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/ClassicalRungeKuttaStepInterpolator.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/ClassicalRungeKuttaStepInterpolator.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/ClassicalRungeKuttaStepInterpolator.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/ClassicalRungeKuttaStepInterpolator.java Tue Feb 14 16:17:55 2012
@@ -15,9 +15,9 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.ode.nonstiff;
+package org.apache.commons.math3.ode.nonstiff;
 
-import org.apache.commons.math.ode.sampling.StepInterpolator;
+import org.apache.commons.math3.ode.sampling.StepInterpolator;
 
 /**
  * This class implements a step interpolator for the classical fourth

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/DormandPrince54Integrator.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/DormandPrince54Integrator.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/DormandPrince54Integrator.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/DormandPrince54Integrator.java Tue Feb 14 16:17:55 2012
@@ -15,9 +15,9 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.ode.nonstiff;
+package org.apache.commons.math3.ode.nonstiff;
 
-import org.apache.commons.math.util.FastMath;
+import org.apache.commons.math3.util.FastMath;
 
 
 /**

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/DormandPrince54StepInterpolator.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/DormandPrince54StepInterpolator.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/DormandPrince54StepInterpolator.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/DormandPrince54StepInterpolator.java Tue Feb 14 16:17:55 2012
@@ -15,11 +15,11 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.ode.nonstiff;
+package org.apache.commons.math3.ode.nonstiff;
 
-import org.apache.commons.math.ode.AbstractIntegrator;
-import org.apache.commons.math.ode.EquationsMapper;
-import org.apache.commons.math.ode.sampling.StepInterpolator;
+import org.apache.commons.math3.ode.AbstractIntegrator;
+import org.apache.commons.math3.ode.EquationsMapper;
+import org.apache.commons.math3.ode.sampling.StepInterpolator;
 
 /**
  * This class represents an interpolator over the last step during an

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/DormandPrince853Integrator.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/DormandPrince853Integrator.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/DormandPrince853Integrator.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/DormandPrince853Integrator.java Tue Feb 14 16:17:55 2012
@@ -15,9 +15,9 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.ode.nonstiff;
+package org.apache.commons.math3.ode.nonstiff;
 
-import org.apache.commons.math.util.FastMath;
+import org.apache.commons.math3.util.FastMath;
 
 
 /**

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/DormandPrince853StepInterpolator.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/DormandPrince853StepInterpolator.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/DormandPrince853StepInterpolator.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/DormandPrince853StepInterpolator.java Tue Feb 14 16:17:55 2012
@@ -15,15 +15,15 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.ode.nonstiff;
+package org.apache.commons.math3.ode.nonstiff;
 
 import java.io.IOException;
 import java.io.ObjectInput;
 import java.io.ObjectOutput;
 
-import org.apache.commons.math.ode.AbstractIntegrator;
-import org.apache.commons.math.ode.EquationsMapper;
-import org.apache.commons.math.ode.sampling.StepInterpolator;
+import org.apache.commons.math3.ode.AbstractIntegrator;
+import org.apache.commons.math3.ode.EquationsMapper;
+import org.apache.commons.math3.ode.sampling.StepInterpolator;
 
 /**
  * This class represents an interpolator over the last step during an

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/EmbeddedRungeKuttaIntegrator.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/EmbeddedRungeKuttaIntegrator.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/EmbeddedRungeKuttaIntegrator.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/EmbeddedRungeKuttaIntegrator.java Tue Feb 14 16:17:55 2012
@@ -15,12 +15,12 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.ode.nonstiff;
+package org.apache.commons.math3.ode.nonstiff;
 
-import org.apache.commons.math.exception.MathIllegalArgumentException;
-import org.apache.commons.math.exception.MathIllegalStateException;
-import org.apache.commons.math.ode.ExpandableStatefulODE;
-import org.apache.commons.math.util.FastMath;
+import org.apache.commons.math3.exception.MathIllegalArgumentException;
+import org.apache.commons.math3.exception.MathIllegalStateException;
+import org.apache.commons.math3.ode.ExpandableStatefulODE;
+import org.apache.commons.math3.util.FastMath;
 
 /**
  * This class implements the common part of all embedded Runge-Kutta

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/EulerIntegrator.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/EulerIntegrator.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/EulerIntegrator.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/EulerIntegrator.java Tue Feb 14 16:17:55 2012
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.ode.nonstiff;
+package org.apache.commons.math3.ode.nonstiff;
 
 
 /**

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/EulerStepInterpolator.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/EulerStepInterpolator.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/EulerStepInterpolator.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/EulerStepInterpolator.java Tue Feb 14 16:17:55 2012
@@ -15,9 +15,9 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.ode.nonstiff;
+package org.apache.commons.math3.ode.nonstiff;
 
-import org.apache.commons.math.ode.sampling.StepInterpolator;
+import org.apache.commons.math3.ode.sampling.StepInterpolator;
 
 /**
  * This class implements a linear interpolator for step.
@@ -52,7 +52,7 @@ class EulerStepInterpolator
   /** Simple constructor.
    * This constructor builds an instance that is not usable yet, the
    * {@link
-   * org.apache.commons.math.ode.sampling.AbstractStepInterpolator#reinitialize}
+   * org.apache.commons.math3.ode.sampling.AbstractStepInterpolator#reinitialize}
    * method should be called before using the instance in order to
    * initialize the internal arrays. This constructor is used only
    * in order to delay the initialization in some cases. The {@link

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/GillIntegrator.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/GillIntegrator.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/GillIntegrator.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/GillIntegrator.java Tue Feb 14 16:17:55 2012
@@ -15,9 +15,9 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.ode.nonstiff;
+package org.apache.commons.math3.ode.nonstiff;
 
-import org.apache.commons.math.util.FastMath;
+import org.apache.commons.math3.util.FastMath;
 
 
 /**

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/GillStepInterpolator.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/GillStepInterpolator.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/GillStepInterpolator.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/GillStepInterpolator.java Tue Feb 14 16:17:55 2012
@@ -15,10 +15,10 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.ode.nonstiff;
+package org.apache.commons.math3.ode.nonstiff;
 
-import org.apache.commons.math.ode.sampling.StepInterpolator;
-import org.apache.commons.math.util.FastMath;
+import org.apache.commons.math3.ode.sampling.StepInterpolator;
+import org.apache.commons.math3.util.FastMath;
 
 /**
  * This class implements a step interpolator for the Gill fourth
@@ -68,7 +68,7 @@ class GillStepInterpolator
   /** Simple constructor.
    * This constructor builds an instance that is not usable yet, the
    * {@link
-   * org.apache.commons.math.ode.sampling.AbstractStepInterpolator#reinitialize}
+   * org.apache.commons.math3.ode.sampling.AbstractStepInterpolator#reinitialize}
    * method should be called before using the instance in order to
    * initialize the internal arrays. This constructor is used only
    * in order to delay the initialization in some cases. The {@link

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/GraggBulirschStoerIntegrator.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/GraggBulirschStoerIntegrator.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/GraggBulirschStoerIntegrator.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/GraggBulirschStoerIntegrator.java Tue Feb 14 16:17:55 2012
@@ -15,16 +15,16 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.ode.nonstiff;
+package org.apache.commons.math3.ode.nonstiff;
 
-import org.apache.commons.math.analysis.solvers.UnivariateSolver;
-import org.apache.commons.math.exception.MathIllegalArgumentException;
-import org.apache.commons.math.exception.MathIllegalStateException;
-import org.apache.commons.math.ode.ExpandableStatefulODE;
-import org.apache.commons.math.ode.events.EventHandler;
-import org.apache.commons.math.ode.sampling.AbstractStepInterpolator;
-import org.apache.commons.math.ode.sampling.StepHandler;
-import org.apache.commons.math.util.FastMath;
+import org.apache.commons.math3.analysis.solvers.UnivariateSolver;
+import org.apache.commons.math3.exception.MathIllegalArgumentException;
+import org.apache.commons.math3.exception.MathIllegalStateException;
+import org.apache.commons.math3.ode.ExpandableStatefulODE;
+import org.apache.commons.math3.ode.events.EventHandler;
+import org.apache.commons.math3.ode.sampling.AbstractStepInterpolator;
+import org.apache.commons.math3.ode.sampling.StepHandler;
+import org.apache.commons.math3.util.FastMath;
 
 /**
  * This class implements a Gragg-Bulirsch-Stoer integrator for

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/GraggBulirschStoerStepInterpolator.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/GraggBulirschStoerStepInterpolator.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/GraggBulirschStoerStepInterpolator.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/GraggBulirschStoerStepInterpolator.java Tue Feb 14 16:17:55 2012
@@ -15,16 +15,16 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.ode.nonstiff;
+package org.apache.commons.math3.ode.nonstiff;
 
 import java.io.IOException;
 import java.io.ObjectInput;
 import java.io.ObjectOutput;
 
-import org.apache.commons.math.ode.EquationsMapper;
-import org.apache.commons.math.ode.sampling.AbstractStepInterpolator;
-import org.apache.commons.math.ode.sampling.StepInterpolator;
-import org.apache.commons.math.util.FastMath;
+import org.apache.commons.math3.ode.EquationsMapper;
+import org.apache.commons.math3.ode.sampling.AbstractStepInterpolator;
+import org.apache.commons.math3.ode.sampling.StepInterpolator;
+import org.apache.commons.math3.util.FastMath;
 
 /**
  * This class implements an interpolator for the Gragg-Bulirsch-Stoer

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/HighamHall54Integrator.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/HighamHall54Integrator.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/HighamHall54Integrator.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/HighamHall54Integrator.java Tue Feb 14 16:17:55 2012
@@ -15,9 +15,9 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.ode.nonstiff;
+package org.apache.commons.math3.ode.nonstiff;
 
-import org.apache.commons.math.util.FastMath;
+import org.apache.commons.math3.util.FastMath;
 
 
 /**

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/HighamHall54StepInterpolator.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/HighamHall54StepInterpolator.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/HighamHall54StepInterpolator.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/HighamHall54StepInterpolator.java Tue Feb 14 16:17:55 2012
@@ -15,9 +15,9 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.ode.nonstiff;
+package org.apache.commons.math3.ode.nonstiff;
 
-import org.apache.commons.math.ode.sampling.StepInterpolator;
+import org.apache.commons.math3.ode.sampling.StepInterpolator;
 
 /**
  * This class represents an interpolator over the last step during an
@@ -38,7 +38,7 @@ class HighamHall54StepInterpolator
   /** Simple constructor.
    * This constructor builds an instance that is not usable yet, the
    * {@link
-   * org.apache.commons.math.ode.sampling.AbstractStepInterpolator#reinitialize}
+   * org.apache.commons.math3.ode.sampling.AbstractStepInterpolator#reinitialize}
    * method should be called before using the instance in order to
    * initialize the internal arrays. This constructor is used only
    * in order to delay the initialization in some cases. The {@link

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/MidpointIntegrator.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/MidpointIntegrator.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/MidpointIntegrator.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/MidpointIntegrator.java Tue Feb 14 16:17:55 2012
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.ode.nonstiff;
+package org.apache.commons.math3.ode.nonstiff;
 
 
 /**

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/MidpointStepInterpolator.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/MidpointStepInterpolator.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/MidpointStepInterpolator.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/MidpointStepInterpolator.java Tue Feb 14 16:17:55 2012
@@ -15,9 +15,9 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.ode.nonstiff;
+package org.apache.commons.math3.ode.nonstiff;
 
-import org.apache.commons.math.ode.sampling.StepInterpolator;
+import org.apache.commons.math3.ode.sampling.StepInterpolator;
 
 /**
  * This class implements a step interpolator for second order
@@ -54,7 +54,7 @@ class MidpointStepInterpolator
   /** Simple constructor.
    * This constructor builds an instance that is not usable yet, the
    * {@link
-   * org.apache.commons.math.ode.sampling.AbstractStepInterpolator#reinitialize}
+   * org.apache.commons.math3.ode.sampling.AbstractStepInterpolator#reinitialize}
    * method should be called before using the instance in order to
    * initialize the internal arrays. This constructor is used only
    * in order to delay the initialization in some cases. The {@link

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/RungeKuttaIntegrator.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/RungeKuttaIntegrator.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/RungeKuttaIntegrator.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/RungeKuttaIntegrator.java Tue Feb 14 16:17:55 2012
@@ -15,14 +15,14 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.ode.nonstiff;
+package org.apache.commons.math3.ode.nonstiff;
 
 
-import org.apache.commons.math.exception.MathIllegalArgumentException;
-import org.apache.commons.math.exception.MathIllegalStateException;
-import org.apache.commons.math.ode.AbstractIntegrator;
-import org.apache.commons.math.ode.ExpandableStatefulODE;
-import org.apache.commons.math.util.FastMath;
+import org.apache.commons.math3.exception.MathIllegalArgumentException;
+import org.apache.commons.math3.exception.MathIllegalStateException;
+import org.apache.commons.math3.ode.AbstractIntegrator;
+import org.apache.commons.math3.ode.ExpandableStatefulODE;
+import org.apache.commons.math3.util.FastMath;
 
 /**
  * This class implements the common part of all fixed step Runge-Kutta

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/RungeKuttaStepInterpolator.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/RungeKuttaStepInterpolator.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/RungeKuttaStepInterpolator.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/RungeKuttaStepInterpolator.java Tue Feb 14 16:17:55 2012
@@ -15,15 +15,15 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.ode.nonstiff;
+package org.apache.commons.math3.ode.nonstiff;
 
 import java.io.IOException;
 import java.io.ObjectInput;
 import java.io.ObjectOutput;
 
-import org.apache.commons.math.ode.AbstractIntegrator;
-import org.apache.commons.math.ode.EquationsMapper;
-import org.apache.commons.math.ode.sampling.AbstractStepInterpolator;
+import org.apache.commons.math3.ode.AbstractIntegrator;
+import org.apache.commons.math3.ode.EquationsMapper;
+import org.apache.commons.math3.ode.sampling.AbstractStepInterpolator;
 
 /** This class represents an interpolator over the last step during an
  * ODE integration for Runge-Kutta and embedded Runge-Kutta integrators.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/ThreeEighthesIntegrator.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/ThreeEighthesIntegrator.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/ThreeEighthesIntegrator.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/ThreeEighthesIntegrator.java Tue Feb 14 16:17:55 2012
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.ode.nonstiff;
+package org.apache.commons.math3.ode.nonstiff;
 
 
 /**

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/ThreeEighthesStepInterpolator.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/ThreeEighthesStepInterpolator.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/ThreeEighthesStepInterpolator.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/ThreeEighthesStepInterpolator.java Tue Feb 14 16:17:55 2012
@@ -15,9 +15,9 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.ode.nonstiff;
+package org.apache.commons.math3.ode.nonstiff;
 
-import org.apache.commons.math.ode.sampling.StepInterpolator;
+import org.apache.commons.math3.ode.sampling.StepInterpolator;
 
 /**
  * This class implements a step interpolator for the 3/8 fourth
@@ -64,7 +64,7 @@ class ThreeEighthesStepInterpolator
   /** Simple constructor.
    * This constructor builds an instance that is not usable yet, the
    * {@link
-   * org.apache.commons.math.ode.sampling.AbstractStepInterpolator#reinitialize}
+   * org.apache.commons.math3.ode.sampling.AbstractStepInterpolator#reinitialize}
    * method should be called before using the instance in order to
    * initialize the internal arrays. This constructor is used only
    * in order to delay the initialization in some cases. The {@link

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/package-info.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/package-info.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/package-info.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/package-info.java Tue Feb 14 16:17:55 2012
@@ -22,4 +22,4 @@
  *
  *
  */
-package org.apache.commons.math.ode.nonstiff;
+package org.apache.commons.math3.ode.nonstiff;
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/FirstOrderIntegrator.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/FirstOrderIntegrator.java Tue Feb 14 16:17:55 2012
@@ -15,10 +15,10 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.ode;
+package org.apache.commons.math3.ode;
 
-import org.apache.commons.math.exception.MathIllegalArgumentException;
-import org.apache.commons.math.exception.MathIllegalStateException;
+import org.apache.commons.math3.exception.MathIllegalArgumentException;
+import org.apache.commons.math3.exception.MathIllegalStateException;
 
 /** This interface represents a first order integrator for
  * differential equations.
@@ -29,8 +29,8 @@ import org.apache.commons.math.exception
  * FirstOrderDifferentialEquations} interface.</p>
  *
  * @see FirstOrderDifferentialEquations
- * @see org.apache.commons.math.ode.sampling.StepHandler
- * @see org.apache.commons.math.ode.events.EventHandler
+ * @see org.apache.commons.math3.ode.sampling.StepHandler
+ * @see org.apache.commons.math3.ode.events.EventHandler
  * @version $Id$
  * @since 1.2
  */
@@ -51,7 +51,7 @@ public interface FirstOrderIntegrator ex
    *  step (and hence at the end of integration), can be the same object as y0
    * @return stop time, will be the same as target time if integration reached its
    * target, but may be different if some {@link
    * org.apache.commons.math.ode.events.EventHandler} stops it at some point.
    * @throws MathIllegalStateException if the integrator cannot perform integration
    * @throws MathIllegalArgumentException if integration parameters are wrong (typically
    * too small integration span)
@@ -51,7 +51,7 @@ public interface FirstOrderIntegrator ex
    * @return stop time, will be the same as target time if integration reached its
    * target, but may be different if some {@link
-   * org.apache.commons.math.ode.events.EventHandler} stops it at some point.
+   * org.apache.commons.math3.ode.events.EventHandler} stops it at some point.
    * @throws MathIllegalStateException if the integrator cannot perform integration
    * @throws MathIllegalArgumentException if integration parameters are wrong (typically

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/JacobianMatrices.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/JacobianMatrices.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/events/EventHandler.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/events/EventHandler.java Tue Feb 14 16:17:55 2012
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.ode.events;
+package org.apache.commons.math3.ode.events;
 
 /** This interface represents a handler for discrete events triggered
  * during ODE integration.
@@ -73,7 +73,7 @@ public interface EventHandler  {
          * #eventOccurred eventOccurred} method when the integration should
          * go on after the event ending the current step, with a new derivatives
          * vector (which will be retrieved thanks to the {@link
-         * org.apache.commons.math.ode.FirstOrderDifferentialEquations#computeDerivatives}
+         * org.apache.commons.math3.ode.FirstOrderDifferentialEquations#computeDerivatives}
          * method).</p>
          */
         RESET_DERIVATIVES,
@@ -121,7 +121,7 @@ public interface EventHandler  {
    * the step handler itself is called (see below for scheduling). It
    * allows the user to update his internal data to acknowledge the fact
    * the event has been handled (for example setting a flag in the {@link
-   * org.apache.commons.math.ode.FirstOrderDifferentialEquations
+   * org.apache.commons.math3.ode.FirstOrderDifferentialEquations
    * differential equations} to switch the derivatives computation in
    * case of discontinuity), or to direct the integrator to either stop
    * or continue integration, possibly with a reset state or derivatives.</p>
@@ -129,7 +129,7 @@ public interface EventHandler  {
    * <ul>
    *   <li>if {@link Action#STOP} is returned, the step handler will be called
    *   with the <code>isLast</code> flag of the {@link
-   *   org.apache.commons.math.ode.sampling.StepHandler#handleStep handleStep}
+   *   org.apache.commons.math3.ode.sampling.StepHandler#handleStep handleStep}
    *   method set to true and the integration will be stopped,</li>
    *   <li>if {@link Action#RESET_STATE} is returned, the {@link #resetState
    *   resetState} method will be called once the step handler has
@@ -143,28 +143,28 @@ public interface EventHandler  {
    * </ul>
 
    * <p>The scheduling between this method and the {@link
    * org.apache.commons.math.ode.sampling.StepHandler StepHandler} method {@link
    * org.apache.commons.math.ode.sampling.StepHandler#handleStep(
    * org.apache.commons.math.ode.sampling.StepInterpolator, boolean)
    * handleStep(interpolator, isLast)} is to call this method first and
    * <code>handleStep</code> afterwards. This scheduling allows the integrator to
    * pass <code>true</code> as the <code>isLast</code> parameter to the step
    * handler to make it aware the step will be the last one if this method
    * returns {@link Action#STOP}. As the interpolator may be used to navigate back
    * throughout the last step (as {@link
-   * org.apache.commons.math.ode.sampling.StepNormalizer StepNormalizer}
+   * org.apache.commons.math3.ode.sampling.StepNormalizer StepNormalizer}
    * does for example), user code called by this method and user
    * code called by step handlers may experience apparently out of order values
    * of the independent time variable. As an example, if the same user object
    * implements both this {@link EventHandler EventHandler} interface and the
-   * {@link org.apache.commons.math.ode.sampling.FixedStepHandler FixedStepHandler}
+   * {@link org.apache.commons.math3.ode.sampling.FixedStepHandler FixedStepHandler}
    * interface, a <em>forward</em> integration may call its
    * <code>eventOccurred</code> method with t = 10 first and call its
    * <code>handleStep</code> method with t = 9 afterwards. Such out of order
    * calls are limited to the size of the integration step for {@link
    * org.apache.commons.math.ode.sampling.StepHandler variable step handlers} and
    * to the size of the fixed step for {@link
    * org.apache.commons.math.ode.sampling.FixedStepHandler fixed step handlers}.</p>
 
    * @param t current value of the independent <i>time</i> variable
    * @param y array containing the current value of the state vector
@@ -143,28 +143,28 @@ public interface EventHandler  {
 
    * <p>The scheduling between this method and the {@link
-   * org.apache.commons.math.ode.sampling.StepHandler StepHandler} method {@link
-   * org.apache.commons.math.ode.sampling.StepHandler#handleStep(
-   * org.apache.commons.math.ode.sampling.StepInterpolator, boolean)
+   * org.apache.commons.math3.ode.sampling.StepHandler StepHandler} method {@link
+   * org.apache.commons.math3.ode.sampling.StepHandler#handleStep(
+   * org.apache.commons.math3.ode.sampling.StepInterpolator, boolean)
    * handleStep(interpolator, isLast)} is to call this method first and
    * <code>handleStep</code> afterwards. This scheduling allows the integrator to
@@ -143,28 +143,28 @@ public interface EventHandler  {
    * <code>handleStep</code> method with t = 9 afterwards. Such out of order
    * calls are limited to the size of the integration step for {@link
-   * org.apache.commons.math.ode.sampling.StepHandler variable step handlers} and
+   * org.apache.commons.math3.ode.sampling.StepHandler variable step handlers} and
    * to the size of the fixed step for {@link
@@ -143,28 +143,28 @@ public interface EventHandler  {
    * to the size of the fixed step for {@link
-   * org.apache.commons.math.ode.sampling.FixedStepHandler fixed step handlers}.</p>
+   * org.apache.commons.math3.ode.sampling.FixedStepHandler fixed step handlers}.</p>
 
    * @param t current value of the independent <i>time</i> variable

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/events/EventState.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/events/EventState.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================
--- commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/AdaptiveStepsizeIntegrator.java (original)
+++ commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/AdaptiveStepsizeIntegrator.java Tue Feb 14 16:17:55 2012
@@ -15,16 +15,16 @@
  * limitations under the License.
  */
 
-package org.apache.commons.math.ode.nonstiff;
+package org.apache.commons.math3.ode.nonstiff;
 
-import org.apache.commons.math.exception.DimensionMismatchException;
-import org.apache.commons.math.exception.MathIllegalArgumentException;
-import org.apache.commons.math.exception.MathIllegalStateException;
-import org.apache.commons.math.exception.NumberIsTooSmallException;
-import org.apache.commons.math.exception.util.LocalizedFormats;
-import org.apache.commons.math.ode.AbstractIntegrator;
-import org.apache.commons.math.ode.ExpandableStatefulODE;
-import org.apache.commons.math.util.FastMath;
+import org.apache.commons.math3.exception.DimensionMismatchException;
+import org.apache.commons.math3.exception.MathIllegalArgumentException;
+import org.apache.commons.math3.exception.MathIllegalStateException;
+import org.apache.commons.math3.exception.NumberIsTooSmallException;
+import org.apache.commons.math3.exception.util.LocalizedFormats;
+import org.apache.commons.math3.ode.AbstractIntegrator;
+import org.apache.commons.math3.ode.ExpandableStatefulODE;
+import org.apache.commons.math3.util.FastMath;
 
 /**
  * This abstract class holds the common part of all adaptive
@@ -44,7 +44,7 @@ import org.apache.commons.math.util.Fast
  * <p>
  * If the Ordinary Differential Equations is an {@link ExpandableStatefulODE
  * extended ODE} rather than a {@link
  * org.apache.commons.math.ode.FirstOrderDifferentialEquations basic ODE}, then
  * <em>only</em> the {@link ExpandableStatefulODE#getPrimaryState() primary part}
  * of the state vector is used for stepsize control, not the complete state vector.
  * </p>
@@ -44,7 +44,7 @@ import org.apache.commons.math.util.Fast
  * If the Ordinary Differential Equations is an {@link ExpandableStatefulODE
  * extended ODE} rather than a {@link
- * org.apache.commons.math.ode.FirstOrderDifferentialEquations basic ODE}, then
+ * org.apache.commons.math3.ode.FirstOrderDifferentialEquations basic ODE}, then
  * <em>only</em> the {@link ExpandableStatefulODE#getPrimaryState() primary part}
  * of the state vector is used for stepsize control, not the complete state vector.

Modified: commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/ClassicalRungeKuttaIntegrator.java
URL: http://svn.apache.org/viewvc/commons/proper/math/trunk/src/main/java/org/apache/commons/math3/ode/nonstiff/ClassicalRungeKuttaIntegrator.java?rev=1244107&r1=1243975&r2=1244107&view=diff
==============================================================================